﻿

----------------------------
--      Localization      --
----------------------------

local L = AceLibrary("AceLocale-2.2"):new("BunchOfBarsCore")

L:RegisterTranslations("enUS", function() return {
	["Visual Options"] = true,
	["Options to control the looks of BunchOfBars."] = true,

	["Module Options"] = true,
	["Options for all enabled modules."] = true,

	["Module Padding"] = true,
	["Padding between module parts."] = true,

	["|cffffff00Click|r to lock/unlock unit frames."] = true,
	["|cffffff00Shift-Click|r to open the configuration window."] = true,

	["Position"] = true,
	["The position of this module's frame on the unit frame."] = true,

	["There is a new revision (|cffff0000r%d|r) of |cff00ff00BunchOfBars|r available. Because |cff00ff00BunchOfBars|r is still in development it is highly recommended to install this new version."] = true
}end)

L:RegisterTranslations("koKR", function() return {
	["Visual Options"] = "설정",
	["Options to control the looks of BunchOfBars."] = "프레임 설정",

	["Module Options"] = "모듈 설정",
	["Options for all enabled modules."] = "각 모듈의 설정을 봅니다.",

	["Module Padding"] = "간격",
	["Padding between module parts."] = "각 모듈간 간격을 설정합니다.",

	["|cffffff00Click|r to lock/unlock unit frames."] = "|cffffff00클릭|r하면 프레임을 고정/비고정 합니다.",
	["|cffffff00Shift-Click|r to open the configuration window."] = "|cffffff00쉬프트+클릭|r하면 설정창을 엽니다.",

	["Position"] = "위치",
	["The position of this module's frame on the unit frame."] = "각 모듈의 위치를 설정합니다.",

--	["There is a new revision (|cffff0000r%d|r) of |cff00ff00BunchOfBars|r available. Because |cff00ff00BunchOfBars|r is still in development it is highly recommended to install this new version."] = true
}end)



----------------------------------
--      Local Declaration      --
----------------------------------

local Waterfall = AceLibrary:HasInstance("Waterfall-1.0") and AceLibrary("Waterfall-1.0") or nil

local newrevision



----------------------------------
--      Module Declaration      --
----------------------------------

BunchOfBars = AceLibrary("AceAddon-2.0"):new(
	"AceModuleCore-2.0",
	"AceConsole-2.0",
	"AceEvent-2.0",
	"FuBarPlugin-2.0",
	"AceDB-2.0",

	"AceComm-2.0"
)

BunchOfBars.revision = tonumber(("$Revision: 39856 $"):match("%d+"))
BunchOfBars.version = "r"..BunchOfBars.revision

BunchOfBars.options = {
	type = "group",
	handler = BunchOfBars,
	args = {
		visual = {
			type = "group",
			name = L["Visual Options"],
			desc = L["Options to control the looks of BunchOfBars."],
			args = { }
		},
		module = {
			type = "group",
			name = L["Module Options"],
			desc = L["Options for all enabled modules."],
			args = {
				padding = {
					type  = "range",
					name  = L["Module Padding"],
					desc  = L["Padding between module parts."],
					min   = 0,
					max   = 15,
					step  = 1,
					get   = "GetSetPadding",
					set   = "GetSetPadding",
					order = 98
				},
				header = {
					type = "header",
					name = " ",
					order = 99
				}
			}
		},

		--[[update = {
			type = "execute",
			name = "Check Versions",
			desc = "Check for versions using AceComm",
			func = function()
				AceLibrary("AceComm-2.0"):RegisterAddonVersionReceptor(function(player, addon, version)
					if version then
						BunchOfBars:Print("|cff00ff00"..player.."|r has revision |cffff0000r"..version.."|r")
					end
				end)
				AceLibrary("AceComm-2.0"):QueryAddonVersion("BunchOfBars", "GUILD")
			end
		}]]--
	}
}

BunchOfBars.defaults = { }


-- FuBar settings
BunchOfBars:Inject({
	hasIcon             = "Interface\\Icons\\Ability_Druid_TreeofLife",
	hasNoColor          = true,
	cannotDetachTooltip	= true,
	hideWithoutStandby  = true,
	independentProfile  = true,
	blizzardTooltip     = true,
	hasNoText           = true,
	OnMenuRequest       = BunchOfBars.options
})



----------------------------------
--      Module Functions        --
----------------------------------

function BunchOfBars:OnInitialize()
	self:RegisterDB("BunchOfBarsDB")
	self:RegisterDefaults("profile", self.defaults)

	self:InitializeLayout()

	self:RegisterChatCommand({"/bob", "/BunchOfBars"}, self.options)

	if Waterfall then
		Waterfall:Register(
			"BunchOfBars",
			"aceOptions", self.options,
			"treeType", "SECTIONS",
			"colorR", 0, "colorG", 0, "colorB", 1
		)
	end

	newrevision = self.revision
end


function BunchOfBars:OnClick(button)
	if IsShiftKeyDown() and Waterfall then
		Waterfall:Open("BunchOfBars")
	else
		self.db.profile.visual.locked = not self.db.profile.visual.locked
		self:UpdateTooltip()
	end
end


function BunchOfBars:OnTooltipUpdate()
	GameTooltip:AddLine("BunchOfBars")
	GameTooltip:AddLine(" ")
	GameTooltip:AddDoubleLine(LOCKED..":", (self.db.profile.visual.locked and YES or NO), 1, 1, 0, 1, 1, 1) -- LOCKED, YES and NO are defined and translated somewher in blizz code
	GameTooltip:AddLine(" ")
	GameTooltip:AddLine(L["|cffffff00Click|r to lock/unlock unit frames."], 0.2, 1, 0.2)

	if Waterfall then
		GameTooltip:AddLine(L["|cffffff00Shift-Click|r to open the configuration window."], 0.2, 1, 0.2)
	end
end


function BunchOfBars:RegisterModules()
	for name,module in self:IterateModules() do
		-- make sure we show the highest reversion number
		if module.revision and module.revision > self.revision then -- TODO: remove the if "module.revision and" ...
			self.version  = "r"..module.revision
			self.revision = module.revision
		end

		if not module.db then
			self:RegisterDefaults(name, "profile", module.defaultDB)
			module.db = self:AcquireDBNamespace(name)
		end

		if module.options or module.db.profile.position then
			self.options.args.module.args[name] = {
				type    = "group",
				handler = module,
				name    = module.options and module.options.name or name,
				desc    = string.format("Options for %s.", module.options and module.options.name or name),
				args    = module.options and module.options.args or {}
			}
		end

		if module.db.profile.position then
			self.options.args.module.args[name].args.position = { -- Nice.
				type = "range",
				name = L["Position"],
				desc = L["The position of this module's frame on the unit frame."],
				min  = 1,
				max  = 10,
				step = 1,
				get  = function() return module.db.profile.position end,
				set  = function(v)
					if module.db.profile.position ~= v then
						module.db.profile.position = v
						BunchOfBars:UpdateLayoutOrder()
						BunchOfBars:UpdateLayouts()
					end
				end
			}
		end
	end
end


function BunchOfBars:CHAT_MSG_ADDON(prefix, message, dist, sender)
	if prefix ~= "BunchOfBars" then return end

	local num = tonumber(message)
	if num > newrevision then
		newrevision = num

		self:ScheduleEvent("BunchOfBars_Version", self.NewRevision, 10, self)
	elseif num < newrevision then
		SendAddonMessage("BunchOfBars", newrevision, "WHISPER", sender)

	--	self:Print("|cff0000ff"..sender.."|r has revision |cffff0000r"..message.."|r")
	--else
	--	self:Print("|cff0000ff"..sender.."|r has revision |cff00ff00r"..message.."|r")
	end
end


function BunchOfBars:NewRevision()
	self:UnregisterEvent("CHAT_MSG_ADDON")
	BunchOfBars:Print(string.format(L["There is a new revision (|cffff0000r%d|r) of |cff00ff00BunchOfBars|r available. Because |cff00ff00BunchOfBars|r is still in development it is highly recommended to install this new version."], newrevision))
end
